@@ -1,7 +1,7 @@
 /* -*-pgsql-c-*- */
 /*
  *
- * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.6 2003/07/20 14:44:37 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.7 2004/02/27 10:15:57 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -48,6 +48,9 @@
 /* pid file directory */
 #define DEFAULT_LOGDIR "/tmp"
 
+/* Unix domain socket directory */
+#define DEFAULT_SOCKET_DIR "/tmp"
+
 /* pid file name */
 #define PID_FILE_NAME "pgpool.pid"
 
@@ -73,7 +76,8 @@ typedef struct {
     int	child_life_time;	/* if idle for this seconds, child exits */
     int	connection_life_time;	/* if idle for this seconds, connection closes */
     int	max_pool;	/* max # of connection pool per child */
-    char *logdir;
+    char *logdir;		/* logging directory */
+    char *socket_dir;	/* Unix domain socket directory */
 
 	/* followings do not exist in the configuration file */
     char	*current_backend_host_name;	/* current backend host name */
